# Semi-ATE-Metis
STDF to PANDAS data frames conversion.

[![CI](https://github.com/Semi-ATE/Metis/workflows/CI/badge.svg?branch=main)](https://github.com/Semi-ATE/Metis/actions?query=workflow%3ACI)
[![CD](https://github.com/Semi-ATE/Metis/workflows/CD/badge.svg)](https://github.com/Semi-ATE/Metis/actions?query=workflow%3ACD)

[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/Semi-ATE/Metis?color=blue&label=GitHub&sort=semver)](https://github.com/Semi-ATE/Metis/releases/latest)
[![GitHub commits since latest release (by date)](https://img.shields.io/github/commits-since/Semi-ATE/Metis/latest)](https://github.com/Semi-ATE/Metis)
[![PyPI](https://img.shields.io/pypi/v/Semi-ATE-Metis?color=blue&label=PyPI)](https://pypi.org/project/Semi-ATE-Metis/)


[![GitHub issues](https://img.shields.io/github/issues/Semi-ATE/Metis)](https://github.com/Semi-ATE/Metis/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/Semi-ATE/Metis)](https://github.com/Semi-ATE/Metis/pulls)

[![codecov](https://codecov.io/gh/Semi-ATE/Metis/branch/main/graph/badge.svg?token=BAP0H9OMED)](https://codecov.io/gh/Semi-ATE/Metis)
